@@ -1,16 +1,15 @@
 #include <stdio.h>
 #include <io.h>
+#include "ystring.h"
 
 int scan_ino;
 
-Scandir(dirpath,func,arg1,arg2,arg3)
-	char *dirpath;
-	int (*func)();
-	char *arg1,*arg2,*arg3;
+int Scandir(const char *dirpath,int(*func)(const char*,...),...)
 {	struct _finddata_t filedata;
 	long File;
 	int rcode = -1;
 	char cwd[1024];
+	VARGS(4,func);
 
 	if( getcwd(cwd,sizeof(cwd)) == 0L )
 		return -1;
@@ -25,7 +24,7 @@ Scandir(dirpath,func,arg1,arg2,arg3)
 		return -1;
 
 	do {
-		if( rcode = (*func)(filedata.name,arg1,arg2,arg3) )
+		if( rcode = (*func)(filedata.name,VA4) )
 			break;
 
 	} while ( _findnext(File,&filedata) == 0 );
@@ -39,7 +38,4 @@ printit(file)
 	printf("- %s\n",file);
 	return 0;
 }
-main(ac,av) char *av[]; {
-	Scandir(av[1],printit);
-}
 */
