@@ -570,6 +570,30 @@ void set_nodelay(int sock,int onoff)
 	GETsockopt(sock,IPPROTO_TCP,TCP_NODELAY,&oon,&len);
 	syslog_DEBUG("TCP_NODELAY[%d] %d -> %d\n",sock,ooo,oon);
 }
+void set_cork(int sock,int onoff){
+	int ooo,oon,len;
+
+#ifdef TCP_CORK
+	len = sizeof(ooo);
+	GETsockopt(sock,IPPROTO_TCP,TCP_CORK,&ooo,&len);
+	SETsockopt(sock,IPPROTO_TCP,TCP_CORK,&onoff,sizeof(onoff));
+	len = sizeof(oon);
+	GETsockopt(sock,IPPROTO_TCP,TCP_CORK,&oon,&len);
+	syslog_DEBUG("TCP_CORK[%d] %d -> %d\n",sock,ooo,oon);
+#endif
+}
+void set_nopush(int sock,int onoff){
+	int ooo,oon,len;
+
+#ifdef TCP_NOPUSH
+	len = sizeof(ooo);
+	GETsockopt(sock,IPPROTO_TCP,TCP_NOPUSH,&ooo,&len);
+	SETsockopt(sock,IPPROTO_TCP,TCP_NOPUSH,&onoff,sizeof(onoff));
+	len = sizeof(oon);
+	GETsockopt(sock,IPPROTO_TCP,TCP_NOPUSH,&oon,&len);
+	syslog_DEBUG("TCP_NOPUSH[%d] %d -> %d\n",sock,ooo,oon);
+#endif
+}
 int setsockSHARE(int sock,int onoff)
 {
 #ifdef SO_REUSEPORT
