@@ -16,8 +16,8 @@ OR IMPLIED WARRANTIES.
 #include "log.h"
 
 #define NAME	"DeleGate"
-#define VERSION	"9.0.1"
-#define DATE	"May 3, 2005"
+#define VERSION	"9.0.2"
+#define DATE	"May 18, 2005"
 #define AUTHOR	"Yutaka Sato"
 #define A_ORG	"National Institute of Advanced Industrial Science and Technology"
 #define A_EMAIL	"ysato AT delegate DOT org"
@@ -32,7 +32,7 @@ static char _VERSION[32] = VERSION;
 static char _DATE[32] = DATE;
 static char DGSIGN_default[] = "VRPYMD";
 /* DGSIGN="V.R.P/Y.M.D" */
-void scan_DGSIGN(DGCtx *Conn,const char *mysig){
+void scan_DGSIGN(DGC*Conn,const char *mysig){
 	if( mysig ){
 		char vf[8];
 		char vs[6][32];
